@@ -5,7 +5,10 @@ from mw_python_sdk import (
     upload_file,
     DatasetConstructor,
 )
+import logging
 
+logging.basicConfig()
+logging.getLogger().setLevel(logging.DEBUG)
 
 class TestCreateDataset(unittest.TestCase):
     def test_dataset_create(self):
